@@ -47,20 +47,45 @@ def setup(app):
     app.add_role("textfield", textfield_role)
     app.add_config_value(
         "activecode_div_class",
-        "runestone explainer ac_section alert alert-warning",
+        "runestone explainer ac_section",
         "html",
     )
     app.add_config_value("activecode_hide_load_history", False, "html")
     app.add_config_value("wasm_uri", "/_static", "html")
 
-    app.add_node(ActivcodeNode, html=(visit_ac_node, depart_ac_node))
+    app.add_node(ActivecodeNode, html=(visit_ac_html, depart_ac_html),
+                 xml=(visit_ac_xml, depart_ac_xml))
 
     app.connect("doctree-resolved", process_activcode_nodes)
     app.connect("env-purge-doc", purge_activecodes)
 
 
+XML_EX_START = """
+<exercise label="{divid}">
+    <statement>
+"""
+
+XML_EX_END = """
+    </statement>
+    <program xml:id="{divid}_editor" interactive='activecode' language="{language}">
+        <input>
+{initialcode}
+        </input>
+    </program>
+</exercise>
+"""
+
+XML_LISTING_START = """
+    <program xml:id="{divid}" interactive='activecode' language="{language}">
+        <input>
+{initialcode}
+        </input>
+    </program>
+"""
+
+
 TEMPLATE_START = """
-<div class="%(divclass)s">
+<div class="%(divclass)s %(optclass)s">
 <div data-component="activecode" id=%(divid)s data-question_label="%(question_label)s">
 <div id=%(divid)s_question class="ac_question col-md-12">
 """
@@ -79,51 +104,58 @@ TEMPLATE_END = """
 """
 
 
-class ActivcodeNode(nodes.General, nodes.Element, RunestoneIdNode):
-    def __init__(self, content, **kwargs):
-        """
+class ActivecodeNode(nodes.General, nodes.Element, RunestoneIdNode):
+    pass
 
-        Arguments:
-        - `self`:
-        - `content`:
-        """
-        super(ActivcodeNode, self).__init__(name=content["name"], **kwargs)
-        self.runestone_options = content
 
+def visit_ac_xml(self, node):
+    if node["runestone_options"]["has_problem_statement"]:
+        res = XML_EX_START.format(**node["runestone_options"])
+        self.output.append(res)
+    else:
+        node["runestone_options"]["initialcode"] = node["runestone_options"]["initialcode"].replace(
+            "<", "&lt;").replace(">", "&gt;")
+
+
+def depart_ac_xml(self, node):
+    if node["runestone_options"]["has_problem_statement"]:
+        res = XML_EX_END.format(**node["runestone_options"])
+        self.output.append(res)
+    else:
+        res = XML_LISTING_START.format(**node["runestone_options"])
+        self.output.append(res)
 
 # self for these functions is an instance of the writer class.  For example
 # in html, self is sphinx.writers.html.SmartyPantsHTMLTranslator
 # The node that is passed as a parameter is an instance of our node class.
-def visit_ac_node(self, node):
+
+
+def visit_ac_html(self, node):
     # print self.settings.env.activecodecounter
 
-    # todo:  handle above in node.runestone_options
-    # todo handle  'hidecode' not in node.runestone_options:
-    # todo:  handle if 'gradebutton' in node.runestone_options: res += GRADES
+    node["delimiter"] = "_start__{}_".format(node["runestone_options"]["divid"])
 
-    node.delimiter = "_start__{}_".format(node.runestone_options["divid"])
+    self.body.append(node["delimiter"])
 
-    self.body.append(node.delimiter)
-
-    res = TEMPLATE_START % node.runestone_options
+    res = TEMPLATE_START % node["runestone_options"]
     self.body.append(res)
 
 
-def depart_ac_node(self, node):
+def depart_ac_html(self, node):
     """This is called at the start of processing an activecode node.  If activecode had recursive nodes
-    etc and did not want to do all of the processing in visit_ac_node any finishing touches could be
+    etc and did not want to do all of the processing in visit_ac_html any finishing touches could be
     added here.
     """
-    res = TEMPLATE_END % node.runestone_options
+    res = TEMPLATE_END % node["runestone_options"]
     self.body.append(res)
 
     addHTMLToDB(
-        node.runestone_options["divid"],
-        node.runestone_options["basecourse"],
-        "".join(self.body[self.body.index(node.delimiter) + 1 :]),
+        node["runestone_options"]["divid"],
+        node["runestone_options"]["basecourse"],
+        "".join(self.body[self.body.index(node["delimiter"]) + 1 :]),
     )
 
-    self.body.remove(node.delimiter)
+    self.body.remove(node["delimiter"])
 
 
 def process_activcode_nodes(app, env, docname):
@@ -241,7 +273,13 @@ class ActiveCode(RunestoneIdDirective):
         else:
             source = "\n"
 
-        self.explain_text = explain_text or ["Not an Exercise"]
+        if explain_text:
+            self.options["has_problem_statement"] = True
+            self.explain_text = explain_text
+        else:
+            self.options["has_problem_statement"] = False
+            self.explain_text = ["Not an Exercise"]
+
         addQuestionToDB(self)
 
         self.options["initialcode"] = source
@@ -448,8 +486,10 @@ class ActiveCode(RunestoneIdDirective):
                     "This should only affect the grading interface. Everything else should be fine."
                 )
 
-        acnode = ActivcodeNode(self.options, rawsource=self.block_text)
-        acnode.source, acnode.line = self.state_machine.get_source_and_line(self.lineno)
+        acnode = ActivecodeNode()
+        acnode["runestone_options"] = self.options
+        acnode["source"], acnode["line"] = self.state_machine.get_source_and_line(
+            self.lineno)
         self.add_name(acnode)  # make this divid available as a target for :ref:
 
         maybeAddToAssignment(self)
