@@ -31,8 +31,11 @@ def setup(app):
 
     app.add_config_value("codelens_div_class", "cd_section", "html")
     app.add_config_value("trace_url", "http://tracer.runestone.academy:5000", "html")
-    app.add_node(CodeLensNode, html=(visit_codelens_html, depart_codelens_html),
-                 xml=(visit_codelens_xml, depart_codelens_xml))
+    app.add_node(
+        CodeLensNode,
+        html=(visit_codelens_html, depart_codelens_html),
+        xml=(visit_codelens_xml, depart_codelens_xml),
+    )
 
 
 #  data-tracefile="pytutor-embed-demo/java.json"
@@ -64,7 +67,7 @@ allTraceData["%(divid)s"] = %(tracedata)s;
 """
 
 PTX_TEMPLATE = """
-<program xml:id="{divid} interactive="codelens" language="{language}>
+<program xml:id="{divid}" interactive="codelens" language="{language}">
     <input>
 {source}
     </input>
@@ -79,18 +82,26 @@ class CodeLensNode(nodes.General, nodes.Element, RunestoneIdNode):
 def visit_codelens_xml(self, node):
     html = VIS
     if "caption" not in node["runestone_options"]:
-        node["runestone_options"]["caption"] = node["runestone_options"]["question_label"]
+        node["runestone_options"]["caption"] = node["runestone_options"][
+            "question_label"
+        ]
     if "tracedata" in node["runestone_options"]:
-        node["runestone_options"]["tracedata"] = node["runestone_options"]["tracedata"].replace(
-            "<", "&lt;").replace(">", "&gt;")
+        node["runestone_options"]["tracedata"] = (
+            node["runestone_options"]["tracedata"]
+            .replace("<", "&lt;")
+            .replace(">", "&gt;")
+        )
 
     res = PTX_TEMPLATE.format(**node["runestone_options"])
+    self.output.append(res)
 
 
 def visit_codelens_html(self, node):
     html = VIS
     if "caption" not in node["runestone_options"]:
-        node["runestone_options"]["caption"] = node["runestone_options"]["question_label"]
+        node["runestone_options"]["caption"] = node["runestone_options"][
+            "question_label"
+        ]
     if "tracedata" in node["runestone_options"]:
         html += DATA
     else:
@@ -99,7 +110,9 @@ def visit_codelens_html(self, node):
 
     self.body.append(html)
     addHTMLToDB(
-        node["runestone_options"]["divid"], node["runestone_options"]["basecourse"], html
+        node["runestone_options"]["divid"],
+        node["runestone_options"]["basecourse"],
+        html,
     )
 
 
@@ -149,24 +162,24 @@ def depart_codelens_xml(self, node):
 
 class Codelens(RunestoneIdDirective):
     """
-.. codelens:: uniqueid
-   :tracedata: Autogenerated or provided
-   :caption: caption below
-   :showoutput: show stdout from program
-   :question: Text of question to ask on breakline
-   :correct: correct answer to the question
-   :feedback: feedback for incorrect answers
-   :breakline: Line to stop on and pop up a question dialog
-   :python: either py2 or py3
+    .. codelens:: uniqueid
+       :tracedata: Autogenerated or provided
+       :caption: caption below
+       :showoutput: show stdout from program
+       :question: Text of question to ask on breakline
+       :correct: correct answer to the question
+       :feedback: feedback for incorrect answers
+       :breakline: Line to stop on and pop up a question dialog
+       :python: either py2 or py3
 
-    x = 0
-    for i in range(10):
-       x = x + i
+        x = 0
+        for i in range(10):
+           x = x + i
 
 
-config values (conf.py):
+    config values (conf.py):
 
-- codelens_div_class - custom CSS class of the component's outermost div
+    - codelens_div_class - custom CSS class of the component's outermost div
     """
 
     required_arguments = 1
